# Python package for global search

## Description

This is the Python part of the GlobalSearch project

## Building Python distribution

```
$ python3 setup.py sdist bdist_wheel
```

## Testing

To run the unit test suite

```
$ test/run_tests.sh
```
